# -*- coding:utf-8 -*-
# @time:2022/12/2710:59
# @author:LX
# @file:test_gradientBar.py
# @software:PyCharm
from PyQtGuiLib.header import (
    PYQT_VERSIONS,
    sys,
    QApplication,
    QMainWindow,
    QThread,
    Signal,
    QColor,
    QThread
)

from PyQtGuiLib.core.progressBar import GradientBar


class DurationTimeThread(QThread):
    added = Signal(int)
    def __init__(self,*args,**kwargs):
        super().__init__(*args,**kwargs)


    def run(self) -> None:
        n=1
        while True:
            self.added.emit(n)
            n+=1
            self.msleep(80)
            if n == 100+1:
                break

'''
    线性渐变进度条 测试用例
'''

class TestGradientBar(QMainWindow):
    def __init__(self,*args,**kwargs):
        super().__init__(*args,**kwargs)
        self.resize(800,500)

        self.gbar = GradientBar(self)
        self.gbar.move(50,50)
        self.gbar.resize(500,10)
        self.gbar.setValue(0)
        self.gbar.setColorAts(
            [(0.2, QColor(170, 170, 255)), (0.4, QColor(170, 255, 127)), (0.6, QColor(85, 170, 127))]
        )
        # self.gbar.appendColor((0.5,QColor(85, 85, 127)))
        self.gbar.setRadius(3)

        self.th = DurationTimeThread()
        self.th.added.connect(self.test)
        self.th.start()

    def test(self,n):
        print(n)
        # if n > 20 and n <50:
        #     self.gbar.setRadius(2)
        # elif n>50:
        #     self.gbar.setRadius(5)
        self.gbar.setValue(n)


if __name__ == '__main__':
    app = QApplication(sys.argv)
    win = TestGradientBar()
    win.show()

    if PYQT_VERSIONS in ["PyQt6", "PySide6"]:
        sys.exit(app.exec())
    else:
        sys.exit(app.exec_())


# -*- coding:utf-8 -*-
# @time:2023/1/68:49
# @author:LX
# @file:qt.py
# @software:PyCharm
from PyQtGuiLib.header.versions import PYQT_VERSIONS
from PyQtGuiLib.header import Qt,QPainter,QStyle,QSizePolicy


if PYQT_VERSIONS == "PyQt5"  :
    FramelessWindowHint = Qt.FramelessWindowHint
    ArrowCursor = Qt.ArrowCursor
    SizeFDiagCursor = Qt.SizeFDiagCursor
    SizeBDiagCursor = Qt.SizeBDiagCursor
    SizeHorCursor = Qt.SizeHorCursor
    SizeVerCursor = Qt.SizeVerCursor
    LeftButton = Qt.LeftButton
    OpenHandCursor = Qt.OpenHandCursor
    WA_TranslucentBackground = Qt.WA_TranslucentBackground
    WA_DeleteOnClose = Qt.WA_DeleteOnClose
    WA_StyledBackground = Qt.WA_StyledBackground
    NoBrush = Qt.NoBrush
    NoPen = Qt.NoPen
    Antialiasing = QPainter.Antialiasing
    SmoothPixmapTransform = QPainter.SmoothPixmapTransform
    TextAntialiasing = QPainter.TextAntialiasing
    PE_Widget = QStyle.PE_Widget
    AlignCenter = Qt.AlignCenter
    ScrollBarAlwaysOn = Qt.ScrollBarAlwaysOn
    ScrollBarAlwaysOff = Qt.ScrollBarAlwaysOff
    ScrollBarAsNeeded = Qt.ScrollBarAsNeeded
    SolidLine = Qt.SolidLine
    DashLine = Qt.DashLine
    DotLine = Qt.DotLine
    DashDotLine = Qt.DashDotLine
    DashDotDotLine = Qt.DashDotDotLine
    CustomDashLine = Qt.CustomDashLine
    WindowStaysOnTopHint = Qt.WindowStaysOnTopHint
    Widget = Qt.Widget
    PolicyExpanding = QSizePolicy.Expanding
    PolicyMinimum = QSizePolicy.Minimum
    PolicyPushButton = QSizePolicy.PushButton
    Horizontal = Qt.Horizontal
    Vertical = Qt.Vertical
    PM_LayoutHorizontalSpacing = QStyle.PM_LayoutHorizontalSpacing
    PM_LayoutVerticalSpacing = QStyle.PM_LayoutVerticalSpacing

if PYQT_VERSIONS in ["PyQt6","PySide2","PySide6"]:
    FramelessWindowHint = Qt.WindowType.FramelessWindowHint
    ArrowCursor = Qt.CursorShape.ArrowCursor
    SizeFDiagCursor = Qt.CursorShape.SizeFDiagCursor
    SizeBDiagCursor = Qt.CursorShape.SizeBDiagCursor
    SizeHorCursor = Qt.CursorShape.SizeHorCursor
    SizeVerCursor = Qt.CursorShape.SizeVerCursor
    LeftButton = Qt.MouseButton.LeftButton
    OpenHandCursor = Qt.CursorShape.OpenHandCursor
    WA_TranslucentBackground = Qt.WidgetAttribute.WA_TranslucentBackground
    WA_DeleteOnClose = Qt.WidgetAttribute.WA_DeleteOnClose
    WA_StyledBackground = Qt.WidgetAttribute.WA_StyledBackground
    NoBrush = Qt.BrushStyle.NoBrush
    NoPen = Qt.PenStyle.NoPen
    Antialiasing = QPainter.RenderHint.Antialiasing
    SmoothPixmapTransform = QPainter.RenderHint.SmoothPixmapTransform
    TextAntialiasing = QPainter.RenderHint.TextAntialiasing
    PE_Widget = QStyle.PrimitiveElement.PE_Widget
    AlignCenter = Qt.AlignmentFlag.AlignCenter
    ScrollBarAlwaysOn = Qt.ScrollBarPolicy.ScrollBarAlwaysOn
    ScrollBarAlwaysOff = Qt.ScrollBarPolicy.ScrollBarAlwaysOff
    ScrollBarAsNeeded = Qt.ScrollBarPolicy.ScrollBarAsNeeded
    SolidLine = Qt.PenStyle.SolidLine
    DashLine = Qt.PenStyle.DashLine
    DotLine = Qt.PenStyle.DotLine
    DashDotLine = Qt.PenStyle.DashDotLine
    DashDotDotLine = Qt.PenStyle.DashDotDotLine
    CustomDashLine = Qt.PenStyle.CustomDashLine
    WindowStaysOnTopHint = Qt.WindowType.WindowStaysOnTopHint
    Widget = Qt.WindowType.Widget
    PolicyExpanding = QSizePolicy.Policy.Expanding
    PolicyMinimum = QSizePolicy.Policy.Minimum
    Horizontal = Qt.Orientation.Horizontal
    Vertical = Qt.Orientation.Vertical
    PM_LayoutHorizontalSpacing = QStyle.PixelMetric.PM_LayoutHorizontalSpacing
    PM_LayoutVerticalSpacing = QStyle.PixelMetric.PM_LayoutVerticalSpacing


# -*- coding:utf-8 -*-
# @time:2022/12/1211:45
# @author:LX
# @file:lmlm.py
# @software:PyCharm

'''
    若隐若现
'''
from PyQtGuiLib.header import (
    sys,
    QApplication,
    QPropertyAnimation,
    QWidget,
    QPushButton,
    PYQT_VERSIONS,
    QGraphicsOpacityEffect,
    QThread,
    Signal
)

# 时间
class DurationTimeThread(QThread):
    finished = Signal()

    def __init__(self,lmlm:QGraphicsOpacityEffect,*args,**kwargs):
        super().__init__(*args,**kwargs)
        self.lmlm = lmlm
        self.mode = "show"
        self.dur_time = 3

    def setMode(self,mode:str):
        self.mode = mode

    def setDurationTime(self, seconds: int):
        self.dur_time = seconds

    def run(self):
        n = round((1 / self.dur_time) / 10, 2)
        opacity_v = 0
        if self.mode == "hide":
            opacity_v = 1
            n = -n

        while self.dur_time:
            self.lmlm.setOpacity(opacity_v)
            self.msleep(100)
            opacity_v += n
            if opacity_v >= 1 or opacity_v <= 0:
                break
        self.finished.emit()


# 若隐若现 动画
class LmLmAnimation(QGraphicsOpacityEffect):
    finished = Signal()  # 完成信号

    Show = "show"
    Hide = "hide"

    def __init__(self,*args,**kwargs):
        super().__init__(*args,**kwargs)
        self.dtt = DurationTimeThread(self)

    def setMode(self,mode:str="show"):
        self.dtt.setMode(mode)

    # 这样写是为了,统一api的用法
    def setTargetObject(self,widget:QWidget):
        widget.setGraphicsEffect(self)

    def setDuration(self,msecs:int):
        self.dtt.setDurationTime(msecs//1000)

    def start(self):
        self.dtt.start()
        self.dtt.finished.connect(self.finished)



class Test(QWidget):
    def __init__(self):
        super(Test, self).__init__()
        self.resize(800,600)

        self.btn = QPushButton("测试",self)
        self.btn.resize(150,70)
        self.btn.move(100,100)

        self.op =LmLmAnimation()
        self.op.setMode(LmLmAnimation.Hide)
        self.op.setTargetObject(self.btn)
        self.op.setDuration(5000)
        self.op.start()
        self.op.finished.connect(lambda :print("Dasdasd"))


        '''
        geometry 位置和大小
        pos 位置
        size 大小
        windowOpacity 透明度
        alpha  自定义
        '''
        # self.ani = QPropertyAnimation()
        # self.ani.setTargetObject(self.btn)
        # self.ani.setPropertyName(b"windowOpacity")
        # self.ani.setDuration(10000)
        # self.ani.setStartValue(1)
        # self.ani.setEndValue(0.3)
        # self.ani.setStartValue(QRect(150, 30, 100, 100))
        # self.ani.setEndValue(QRect(150, 30, 200, 200))
        # self.ani.start()


if __name__ == '__main__':
    app = QApplication(sys.argv)
    win = Test()
    win.show()

    if PYQT_VERSIONS == "PyQt6":
        sys.exit(app.exec())
    else:
        sys.exit(app.exec_())


# -*- coding:utf-8 -*-
# @time:2022/12/3013:58
# @author:LX
# @file:test_label.py
# @software:PyCharm
from PyQtGuiLib.header import (
    PYQT_VERSIONS,
    QApplication,
    sys,
    QWidget,
    QLabel,
    QPaintEvent,
    QMouseEvent,
    QKeyEvent,
    Qt
)


class Test(QLabel):
    def __init__(self,*args,**kwargs):
        super().__init__(*args,**kwargs)
        self.resize(200,200)
        self.__text = ""
        self.setText("我是 标签")
        self.setAlignment(Qt.AlignCenter)


    def keyPressEvent(self, ev: QKeyEvent) -> None:
        self.__text +=ev.text()
        self.setText(self.__text)
        super().keyPressEvent(ev)


if __name__ == '__main__':
    app = QApplication(sys.argv)
    win = Test()
    win.show()

    if PYQT_VERSIONS == "PyQt6":
        sys.exit(app.exec())
    else:
        sys.exit(app.exec_())


from PyQtGuiLib.header import (
    PYQT_VERSIONS,
    sys,
    QApplication,
    QPushButton,
    QWidget
)

from PyQtGuiLib.styles import ButtonStyle
from PyQtGuiLib.core import FlowLayout

class TestStyle(QWidget):
    def __init__(self,*args,**kwargs):
        super().__init__(*args,**kwargs)
        self.resize(800, 500)

        self.flow = FlowLayout(self)


        for i in range(50):
            btn = QPushButton("test_{}".format(str(i)), self)
            btn.setFixedSize(130,60)
            # btn.setStyleSheet(ButtonStyle.contrastStyle())  # 互补色样式
            # btn.setStyleSheet(ButtonStyle.randomStyle()) # 随机样式
            btn.setStyleSheet(ButtonStyle.homologyStyle())  # 同色调样式
            self.flow.addWidget(btn)


if __name__ == '__main__':
    app = QApplication(sys.argv)
    win = TestStyle()
    win.show()

    if PYQT_VERSIONS in ["PyQt6", "PySide6"]:
        sys.exit(app.exec())
    else:
        sys.exit(app.exec_())


# -*- coding:utf-8 -*-
# @time:2022/12/3012:41
# @author:LX
# @file:temp_test.py
# @software:PyCharm

from PyQtGuiLib.header import (
    PYQT_VERSIONS,
    QApplication,
    sys,
    QWidget,
    QListWidget,
    QListWidgetItem,
    QComboBox,
    QPaintEvent,
    QPushButton,
    QMouseEvent,
    QAction,
)

class Test(QComboBox):
    def __init__(self,*args,**kwargs):
        super().__init__(*args,**kwargs)


        self.btn = QPushButton("我是下拉框",self)
        self.btn.move(50,50)


        for i in range(5):
            self.addItem("选项{}".format(i))
            # self.addItem(item)
            # item = QListWidgetItem()
            # item.setText("选项{}".format(i))
            # self.addItem(item)


    def mousePressEvent(self, e:QMouseEvent) -> None:
        super().mousePressEvent(e)

    def paintEvent(self, e: QPaintEvent) -> None:
        pass
        # super().paintEvent(e)


if __name__ == '__main__':
    app = QApplication(sys.argv)
    win = Test()
    win.show()

    if PYQT_VERSIONS == "PyQt6":
        sys.exit(app.exec())
    else:
        sys.exit(app.exec_())


from PyQtGuiLib.styles import SkinABC

class ButtonStyle(SkinABC):

    # 偏平风格
    @staticmethod
    def flatStyle(objectName: str = None,**kwargs):
        return ButtonStyle.style(objectName,border_width="0px",backgroundColor="rgb(193, 191, 194)",
                                 color="rgb(254, 252, 255)",**kwargs)

    # 描边风格
    @staticmethod
    def outlineStyle(self,objectName: str = None,**kwargs):
        return ButtonStyle.style(objectName, border_width="1px",border_style=ButtonStyle.BorderSolid,
                                 border_color="rgb(50, 96, 239)",**kwargs)




# -*- coding:utf-8 -*-
# @time:2023/1/55:01
# @author:LX
# @file:draw2.py
# @software:PyCharm
from PyQtGuiLib.header import (
    PYQT_VERSIONS,
    sys,
    QApplication,
    QWidget,
    Signal,
    Qt,
    QFont,
    QColor,
    QPen,
    QPainter,
    QPaintEvent,
    QFontMetricsF,
    QSize,
    QResizeEvent,
    QPropertyAnimation,
    QPoint,
    QThread,
    QPushButton,
    QPainterPath,
    QLinearGradient,
    QRectF,
    QPolygonF,
    QPointF,
    QGridLayout,
    QPalette,
)
from PyQt5.QtWidgets import QStyleOptionFocusRect,QStyle,QPushButton,QStyleFactory
'''
    绘图练习2
'''


class Test1(QWidget):
    def __init__(self,*args,**kwargs):
        super().__init__(*args,**kwargs)
        self.resize(800,600)


    def paintEvent(self, e: QPaintEvent) -> None:
        painter = QPainter(self)

        option = QStyleOptionFocusRect()
        option.initFrom(self)
        # option.backgroundColor=self.palette().color(QPalette.Background)
        option.backgroundColor=QColor(0,255,0)

        self.style().drawPrimitive(QStyle.PE_FrameFocusRect,option,painter,self)

        painter.end()

class Test(QWidget):
    def __init__(self,*args,**kwargs):
        super().__init__(*args,**kwargs)
        self.resize(800,600)
        self.setWindowFlags(Qt.WindowStaysOnTopHint)




if __name__ == '__main__':
    app = QApplication(sys.argv)
    win = Test()
    win.show()

    if PYQT_VERSIONS == "PyQt6":
        sys.exit(app.exec())
    else:
        sys.exit(app.exec_())



from PyQtGuiLib.header.versions import PYQT_VERSIONS

if PYQT_VERSIONS == "PyQt5":
    from PyQt5.QtGui import (
        QCursor,
        QPainter,
        QResizeEvent,
        QMouseEvent,
        QMoveEvent,
        QPaintEvent,
        QInputMethodEvent,
        QKeyEvent,
        QColor,
        QPen,
        QPainterPath,
        QPolygon,
        QPolygonF,
        QFont,
        QLinearGradient,
        QRadialGradient,
        QConicalGradient,
        QFontMetricsF,
        QCloseEvent,
        QBrush,
        QPalette,
        QPixmap,
        QIcon,
    )

if PYQT_VERSIONS == "PyQt6":
    from PyQt6.QtGui import (
        QCursor,
        QPainter,
        QResizeEvent,
        QMouseEvent,
        QMoveEvent,
        QPaintEvent,
        QInputMethodEvent,
        QKeyEvent,
        QColor,
        QPen,
        QPainterPath,
        QPolygon,
        QPolygonF,
        QFont,
        QLinearGradient,
        QRadialGradient,
        QConicalGradient,
        QFontMetricsF,
        QCloseEvent,
        QBrush,
        QPalette,
        QPixmap,
        QIcon,
        QAction,
        QGuiApplication as DesktopWidget,
    )

if PYQT_VERSIONS == "PySide2":
    from PySide2.QtGui import (
        QCursor,
        QPainter,
        QResizeEvent,
        QMouseEvent,
        QMoveEvent,
        QPaintEvent,
        QInputMethodEvent,
        QKeyEvent,
        QColor,
        QPen,
        QPainterPath,
        QPolygon,
        QPolygonF,
        QFont,
        QLinearGradient,
        QRadialGradient,
        QConicalGradient,
        QFontMetricsF,
        QCloseEvent,
        QBrush,
        QPalette,
        QPixmap,
        QIcon,
        QGuiApplication as DesktopWidget,
    )


if PYQT_VERSIONS == "PySide6":
    from PySide6.QtGui import (
        QCursor,
        QPainter,
        QResizeEvent,
        QMouseEvent,
        QMoveEvent,
        QPaintEvent,
        QInputMethodEvent,
        QKeyEvent,
        QColor,
        QPen,
        QPainterPath,
        QPolygon,
        QPolygonF,
        QFont,
        QLinearGradient,
        QRadialGradient,
        QConicalGradient,
        QFontMetricsF,
        QCloseEvent,
        QBrush,
        QPalette,
        QPixmap,
        QIcon,
        QAction,
        QGuiApplication as DesktopWidget,
    )


from PyQtGuiLib.header.Qt.qtWidgets import *
from PyQtGuiLib.header.Qt.qtGui import *
from PyQtGuiLib.header.Qt.qtCore import *
from PyQtGuiLib.header.Qt import qt
from PyQtGuiLib.header.py.common import *

from PyQtGuiLib.header.versions import PYQT_VERSIONS
from PyQtGuiLib.header.utility import is_win_sys, is_mac_sys,desktopCenter,desktopSize,textSize


# 处理mac下无法运行的情况
if is_mac_sys and PYQT_VERSIONS in ["PySide2","PySide6"]:
    os.environ["QT_MAC_WANTS_LAYER"] = "1"



from PyQtGuiLib.header import (
    PYQT_VERSIONS,
    sys,
    QApplication,
    QWidget,
    QThread,
    Signal,
    QColor,
    QSlider,
    QListWidgetItem
)

from PyQtGuiLib.core import ListWidget
from PyQtGuiLib.styles import ButtonStyle


class TestListWidget(QWidget):
    def __init__(self,*args,**kwargs):
        super().__init__(*args,**kwargs)
        self.resize(800,600)

        self.listw = ListWidget(self)
        self.listw.resize(200,300)
        self.listw.move(100,100)
        # self.listw.itemDoubleClicked.connect(lambda :print("asd"))

        for i in range(5):
            widget = QWidget()
            widget.setFixedHeight(30)
            widget.setStyleSheet(ButtonStyle.randomStyle())
            self.listw.addWidget(widget)

if __name__ == '__main__':
    app = QApplication(sys.argv)
    win = TestListWidget()
    win.show()

    if PYQT_VERSIONS in ["PyQt6", "PySide6"]:
        sys.exit(app.exec())
    else:
        sys.exit(app.exec_())


# -*- coding:utf-8 -*-
# @time:2023/1/87:12
# @author:LX
# @file:builtStyleDesigner.py
# @software:PyCharm


from PyQtGuiLib.header import (
    PYQT_VERSIONS,
    sys,
    QApplication,
    QVBoxLayout,
    QResizeEvent,
    QTreeWidgetItem,
    QWidget,
    QSize,
    QPushButton,
    QColorDialog
)
from functools import partial
from PyQtGuiLib.styles.builtStyleDesigner.builtStyleDesignerUI import BuiltStyleDesignerUI
from PyQtGuiLib.styles import ButtonStyle
'''

    内置-样式设计器
'''

class BuiltStyleDesigner(BuiltStyleDesignerUI):
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.resize(1100, 850)

        self.addTree({
            "QPushButton":[("randomStyle","随机样式"),
                           ("contrastStyle","互补色样式"),
                           ("homologyStyle","同色调样式")]
                      })

        # 判断是否已经创建的控件,控件列表,控件数量
        self.is_Controls = False
        self.controls = []
        self.control_number = 35

        # 当前点击的控件名称,方法
        self.cu_click_name = ""
        self.cu_fun = ""

        # ----------
        # 设置一个当前的控件数量
        self.c_number_spin.setValue(self.control_number)

        self.myEvent()

    # 添加控件
    def addControls(self,widget:QWidget,size:QSize=QSize(130,60)):
        widget.setFixedSize(size)
        self.flow.addWidget(widget)

    def addTree(self,tree_dict:dict):
        if not tree_dict:
            return None

        tree = self.treeObj()

        for name,values in tree_dict.items():
            item = QTreeWidgetItem(tree)
            item.setText(0, name)
            for ch,explain in values:
                item_c = QTreeWidgetItem(item)
                item_c.setText(0, ch)
                item_c.setText(1, explain)
                # tree.addTopLevelItem(item)

    def itemDoubleClick_event(self,item:QTreeWidgetItem,column:int):
        text = item.text(column)

        if text[0] == "Q":
            print("父节点:",text)
            if text == "QPushButton":
                if not self.is_Controls:

                    # 设置
                    self.is_Controls = True
                    self.cu_fun = "randomStyle"
                    self.cu_click_name = "QPushButton"

                    for i in range(self.control_number):
                        btn = QPushButton()
                        btn.setText("test_{}".format(i))
                        btn.setStyleSheet(ButtonStyle.randomStyle())
                        btn.clicked.connect(partial(self.qss_event,btn.styleSheet()))
                        self.controls.append(btn)
                        self.addControls(btn)
                else:
                    self.is_Controls = False
                    for w in self.controls:
                        self.flow.removeWidget(w)
                    self.controls.clear()

        else:
            print("子节点:",text)
            if not self.controls:
                return

            # 设置
            self.cu_fun = text

            for w in self.controls:
                if self.cu_click_name == "QPushButton":
                    if text == "randomStyle":
                        w.setStyleSheet(ButtonStyle.randomStyle())
                    elif text == "contrastStyle":
                        w.setStyleSheet(ButtonStyle.contrastStyle())
                    elif text == "homologyStyle":
                        w.setStyleSheet(ButtonStyle.homologyStyle())

    # 控件数量改变事件
    def number_event(self,n:int):
        if not self.controls:
            self.control_number = n
            return

        if n > self.control_number:
            if self.cu_click_name == "QPushButton":
                btn = QPushButton()
                btn.setText("hello")
                self.controls.append(btn)

                if self.cu_fun == "randomStyle":
                    btn.setStyleSheet(ButtonStyle.randomStyle())
                elif self.cu_fun == "contrastStyle":
                    btn.setStyleSheet(ButtonStyle.contrastStyle())
                elif self.cu_fun == "homologyStyle":
                    btn.setStyleSheet(ButtonStyle.homologyStyle())

                btn.clicked.connect(partial(self.qss_event, btn.styleSheet()))
                self.addControls(btn)
        else:
            pop = self.controls.pop(-1)
            pop.clicked.disconnect()
            self.flow.removeWidget(pop)
        self.control_number = n

    # qss代码事件
    def qss_event(self,qss:str):
        self.qssEditObj().clear()
        self.qssEditObj().setText(qss)

    # 修改背景颜色事件
    def background_color_event(self):
        rgb_obj = QColorDialog.getColor()
        rgb = rgb_obj.getRgb()
        self.back_c_btn.setStyleSheet("background-color:rgb({},{},{},{})".format(*rgb))
        self.showObj().setStyleSheet("background-color:rgb({},{},{},{})".format(*rgb))

    def myEvent(self):
        self.treeObj().itemDoubleClicked.connect(self.itemDoubleClick_event)

        self.c_number_spin.valueChanged.connect(self.number_event)
        self.back_c_btn.clicked.connect(self.background_color_event)


    def resizeEvent(self, e:QResizeEvent) -> None:
        self.updateSize()
        super().resizeEvent(e)


if __name__ == '__main__':
    app = QApplication(sys.argv)
    win = BuiltStyleDesigner()
    win.show()

    if PYQT_VERSIONS in ["PyQt6", "PySide6"]:
        sys.exit(app.exec())
    else:
        sys.exit(app.exec_())


from PyQtGuiLib.header import (
    PYQT_VERSIONS,
    sys,
    qt,
    QApplication,
    QWidget,
    QHBoxLayout,
    QGraphicsOpacityEffect,
    QPushButton
)
from PyQtGuiLib.core.widgets import BorderlessWidget



'''
    该窗口一定要通过qss样式,设置背景
    窗口的圆角也需要通过qss来实现,例如: border-radius:50px;
    
    注意使用这个窗口的时候,真正操作的是 widget()返回的窗口,
    所以要添加控件,也是添加在widget()返回的窗口上
'''
# 圆角窗口
class RoundWidget(BorderlessWidget):
    def __init__(self,*args,**kwargs):
        super().__init__(*args,**kwargs)
        self.resize(800,600)
        # 背景透明,去掉窗口边框,去掉边框
        self.setAttribute(qt.WA_TranslucentBackground, True)
        self.setWindowFlags(qt.FramelessWindowHint)
        self.setAttribute(qt.WA_DeleteOnClose)


        self.builtin_widget = '''
#widget{
background-color:gray;
border-radius:50px;
}
        '''
        self.__builtin_style = ""

        self.__hlay = QHBoxLayout(self)
        self.__hlay.setContentsMargins(0,0,0,0)
        self.__hlay.setSpacing(0)

        self.__widget = QWidget()
        self.__hlay.addWidget(self.__widget)
        self.setObjectName("widget")
        self.setStyleSheet(self.builtin_widget)

        # 设置透明度
        self.opacity_effect = QGraphicsOpacityEffect()
        self.opacity_effect.setOpacity(1)
        self.__widget.setGraphicsEffect(self.opacity_effect)

    def setOpacity(self,opacity:float):
        self.opacity_effect.setOpacity(opacity)

    def widget(self) -> QWidget:
        return self.__widget

    def setObjectName(self, name:str) -> None:
        self.__widget.setObjectName(name)

    def setStyleSheet(self, styleSheet:str) -> None:
        self.__widget.setStyleSheet(styleSheet)


if __name__ == '__main__':
    app = QApplication(sys.argv)
    win = RoundWidget()
    win.show()

    if PYQT_VERSIONS == "PyQt6":
        sys.exit(app.exec())
    else:
        sys.exit(app.exec_())


from PyQtGuiLib.header import (
    PYQT_VERSIONS,
    sys,
    QApplication,
    QListWidget,
    QListWidgetItem,
    QWidget,
    QSize,
    QStyledItemDelegate,
    QStyleOptionViewItem,
    QModelIndex
)

'''

    QListWidget 增强版本
'''

class ItemDelegate(QStyledItemDelegate):
    def __init__(self,*args,**kwargs):
        super().__init__(*args,**kwargs)


    def updateEditorGeometry(self, editor:QWidget, option:QStyleOptionViewItem, index:QModelIndex) -> None:
        editor.setGeometry(option.rect)


class ListWidgetItem(QListWidgetItem):
    def __init__(self,*args,**kwargs):
        super().__init__(*args,**kwargs)




class ListWidget(QListWidget):
    def __init__(self,*args,**kwargs):
        super().__init__(*args,**kwargs)


    def addWidget(self,widget:QWidget):
        item = ListWidgetItem()
        item.setSizeHint(QSize(self.width(),widget.height()))
        # self.setItemDelegate(ItemDelegate())
        self.addItem(item)
        self.setItemWidget(item, widget)



import sys
from PyQt5.QtWidgets import QWidget,QApplication,QPushButton,QHBoxLayout,QTableWidget


class Test(QWidget):
    def __init__(self,*args,**kwargs):
        super().__init__(*args,**kwargs)
        self.resize(800,500)

        # 水平布局
        self.hlay = QHBoxLayout(self)

        self.btn = QPushButton("添加QWidget")
        self.btn.clicked.connect(self.addWidget)

        self.hlay.addWidget(self.btn)

    # 添加QWidget
    def addWidget(self,widget):
        widget.setStyleSheet("background-color: rgb(85, 170, 127);")
        widget.show()
        self.hlay.addWidget(widget)

if __name__ == '__main__':
    app = QApplication(sys.argv)
    win = Test()
    win.show()

    sys.exit(app.exec_())


from PyQtGuiLib.header import (
    PYQT_VERSIONS,
    sys,
    QApplication,
    QMainWindow,
    QThread,
    Signal,
    QColor
)

from PyQtGuiLib.core.progressBar import NodeBar


class DurationTimeThread(QThread):
    added = Signal(int)
    def __init__(self,*args,**kwargs):
        super().__init__(*args,**kwargs)


    def run(self) -> None:
        n=1
        while True:
            self.added.emit(n)
            n+=1
            self.msleep(80)
            if n == 100+1:
                break

class TestPullOverWidget(QMainWindow):
    def __init__(self,*args,**kwargs):
        super().__init__(*args,**kwargs)
        self.resize(800,500)

#         self.setObjectName("test")
#         self.setStyleSheet('''
# #test{
# background-color: rgb(25, 25, 25);
# }
#         ''')

        self.nodebar = NodeBar(self)
        self.nodebar.move(50,100)



if __name__ == '__main__':
    app = QApplication(sys.argv)
    win = TestPullOverWidget()
    win.show()

    if PYQT_VERSIONS in ["PyQt6", "PySide6"]:
        sys.exit(app.exec())
    else:
        sys.exit(app.exec_())


# -*- coding:utf-8 -*-
# @time:2022/12/1018:31
# @author:LX
# @file:setup.py
# @software:PyCharm

from distutils.core import setup
from setuptools import find_packages


setup(
    name="PyQtGuiLib",
    packages =find_packages(),
    version="1.1.9.4",
    author="LX",
    author_email = "lx984608061@163.com",
    description = "Python version of the qt component library.",
    long_description=open('README.md', 'r',encoding="utf8").read(),
    long_description_content_type="text/markdown",
    url = "https://github.com/LX-sys/PyQtGuiLib",
    classifiers = [
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ]
)


# -*- coding:utf-8 -*-
# @time:2023/1/36:13
# @author:LX
# @file:test_QAbstractScrollArea.py
# @software:PyCharm

from PyQtGuiLib.header import (
    PYQT_VERSIONS,
    sys,
    QApplication,
    QAbstractScrollArea,
    QWidget,
    Qt,
    QLineEdit,
    QPainter,
    QPaintEvent,
    QResizeEvent,
)

class Test(QLineEdit):
    def __init__(self,*args,**kwargs):
        super().__init__(*args,**kwargs)
        # self.resize(300,300)

        # self.t = QWidget()
        # self.t.setStyleSheet("background-color:red;")

        # self.addScrollBarWidget(self.t, Qt.AlignmentFlag)


if __name__ == '__main__':
    app = QApplication(sys.argv)
    win = Test()
    win.show()

    if PYQT_VERSIONS == "PyQt6":
        sys.exit(app.exec())
    else:
        sys.exit(app.exec_())


# -*- coding:utf-8 -*-
# @time:2023/1/87:03
# @author:LX
# @file:builtStyleDesignerUI.py
# @software:PyCharm
from PyQtGuiLib.header import (
    PYQT_VERSIONS,
    sys,
    QApplication,
    QVBoxLayout,
    QHBoxLayout,
    QWidget,
    QFrame,
    QTreeWidget,
    QSplitter,
    qt,
    QTabWidget,
    QTextEdit,
    QSpinBox,
    QFormLayout,
    QLabel,
    QPushButton
)

'''

    内置-样式设计器 UI 界面
'''

from PyQtGuiLib.core.widgets import BorderlessFrame,TitleBar
from PyQtGuiLib.core import FlowLayout


class BuiltStyleDesignerUI(BorderlessFrame):
    def __init__(self,*args,**kwargs):
        super().__init__(*args,**kwargs)
        self.resize(1100,850)
        self.setObjectName("BuiltStyleDesigner")
        self.InitWidget()

    def InitWidget(self):
        self.setStyleSheet('''
#BuiltStyleDesigner{
background-color:#d4d4d4;
}
#top_rigth_show{
border:2px solid blue;
}
#bottom_left_qss{
font-size:16px;
}
        ''')

        # 创建标题栏
        self.titbar = TitleBar(self)
        self.titbar.setBtnStyle(TitleBar.MacStyle)
        self.titbar.setTitleText("内置-样式设计器")

        # 创建上下布局
        self.sp_vlay = QSplitter(self)
        self.sp_vlay.setHandleWidth(2)
        self.sp_vlay.setGeometry(0,self.titbar.height(),self.size().width(),self.size().height())
        self.sp_vlay.setOrientation(qt.Vertical)

        self.top_widget = QWidget()
        self.bottom_widget = QWidget()

        self.top_widget.setObjectName("top_widget")
        self.bottom_widget.setObjectName("bottom_widget")

        self.sp_vlay.addWidget(self.top_widget)
        self.sp_vlay.addWidget(self.bottom_widget)
        self.sp_vlay.setSizes([self.height()-300,300])

        # 在上布局的QWidget布局
        self.top_hlay = QHBoxLayout(self.top_widget)
        self.top_left_tree = QTreeWidget()
        self.top_left_tree.setColumnCount(2)
        self.top_left_tree.setHeaderLabels(["组件","方法"])
        self.top_left_tree.setMaximumWidth(300)
        self.top_rigth_show = QFrame()
        self.flow = FlowLayout(self.top_rigth_show)
        self.top_left_tree.setObjectName("top_left_tree")
        self.top_rigth_show.setObjectName("top_rigth_show")

        self.top_hlay.addWidget(self.top_left_tree)
        self.top_hlay.addWidget(self.top_rigth_show)

        # 在下布局的QWidget布局
        self.sp_hlay = QSplitter(self.bottom_widget)
        self.sp_hlay.setContentsMargins(9,0,9,5)
        self.sp_hlay.setHandleWidth(2)
        self.sp_hlay.setGeometry(0, 0, self.bottom_widget.width(), self.bottom_widget.height()-self.titbar.height())
        self.sp_hlay.setOrientation(qt.Horizontal)

        self.bottom_left_tab = QTabWidget()
        self.bottom_left_qss = QTextEdit()
        self.bottom_left_tab.setObjectName("bottom_left_tab")
        self.bottom_left_qss.setObjectName("bottom_left_qss")

        self.sp_hlay.addWidget(self.bottom_left_tab)
        self.sp_hlay.addWidget(self.bottom_left_qss)
        self.sp_hlay.setSizes([self.height() - 300, 300])

        # 创建控制台
        self.consoleTab()

        self.sp_vlay.splitterMoved.connect(self.updateSize)

    # 控制台
    def consoleTab(self):
        self.console_widget = QWidget()
        self.bottom_left_tab.addTab(self.console_widget,"控制台")

        # 表单布局
        self.form_lay = QFormLayout(self.console_widget)

        self.c_number_l = QLabel("控件数量")
        self.c_number_spin = QSpinBox()
        self.c_number_spin.setMinimum(1)
        self.c_number_spin.setMaximum(60)

        self.back_c_l = QLabel("背景颜色")
        self.back_c_btn = QPushButton("颜色")

        # self.c_size_l = QLabel("控件大小")
        # self.c_size_l = QPushButton("颜色")

        self.form_lay.addRow(self.c_number_l,self.c_number_spin)
        self.form_lay.addRow(self.back_c_l,self.back_c_btn)

    def updateSize(self):
        self.titbar.updateTitleSize()
        self.sp_vlay.setGeometry(0, self.titbar.height(), self.size().width(), self.size().height())
        self.sp_hlay.setGeometry(0, 0, self.bottom_widget.width(), self.bottom_widget.height()-self.titbar.height())

    def treeObj(self)->QTreeWidget:
        return self.top_left_tree

    def showObj(self)->QFrame:
        return self.top_rigth_show

    def tabObj(self)->QTabWidget:
        return self.bottom_left_tab

    def qssEditObj(self)->QTextEdit:
        return self.bottom_left_qss

    def flowObj(self)->FlowLayout:
        return self.flow